import { DesignSystem } from '@microsoft/fast-foundation';
import { provideTokens } from './design-system-provider';
import * as tokens from './_config/tokens';
import * as values from './_config/values';
export function createDesignSystemProxy(designSystem) {
    return new Proxy(designSystem, {
        get: (target, prop, ...rest) => {
            if (['withPrefix', 'withShadowRootMode', 'withElementDisambiguation'].includes(prop)) {
                throw new Error('Modification of the Design System is not allowed.');
            }
            return Reflect.get(target, prop, ...rest);
        },
    });
}
export const provideDesignSystem = (element, prefix = 'foundation') => {
    if (element) {
        provideTokens(tokens, values, element);
    }
    const designSystem = DesignSystem.getOrCreate(element).withPrefix(prefix);
    return createDesignSystemProxy(designSystem);
};
//# sourceMappingURL=provide-design-system.js.map